@@ -125,6 +125,10 @@ identifiers = [
         '0000-0002-1825-0097', 'http://orcid.org/0000-0002-1825-0097'),
     ('0000-0002-1694-233X', ['orcid', 'isni'], '0000-0002-1694-233X',
         'http://orcid.org/0000-0002-1694-233X'),
+    ('0009-0005-6000-7479', ['orcid', 'isni'], '0009-0005-6000-7479',
+        'http://orcid.org/0009-0005-6000-7479'),
+    ('https://orcid.org/0009-0002-4767-9017', ['orcid', 'url'],
+        '0009-0002-4767-9017', 'http://orcid.org/0009-0002-4767-9017'),
     ('1422-4586-3573-0476', ['isni'], '', ''),
     ('arXiv:1310.2590', ['arxiv', ], 'arXiv:1310.2590',
         'http://arxiv.org/abs/arXiv:1310.2590'),
